==> schedwiclnt-0.1.0.tar.gz: schedwiclnt-0.1.0/src/child_mgnt.h <==
/* Schedwi
   Copyright (C) 2007 Herve Quatremain

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU Library General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

/* child_mgnt.h -- Manage running child processes in a linked list */

#ifndef _CHILD_MGNT_H
#define _CHILD_MGNT_H

#include <schedwi.h>

#if HAVE_SYS_TYPES_H
#include <sys/types.h>
#endif

#include <net_utils_glob.h>

/* Allow the use in C++ code.  */
#ifdef __cplusplus
extern "C" {
#endif

#if HAVE_PID_T
extern int add_child OF((pid_t child, const char *job_id));
#else
extern int add_child OF((int child, const char *job_id));
#endif

#if HAVE_PID_T
extern int delete_child OF((pid_t child, char **job_id));
#else
extern int delete_child OF((int child, char **job_id));
#endif

extern int terminate_job OF((const char *job_id));
extern void print_jobs OF((net_id *fd));

#ifdef __cplusplus
}
#endif  /* C++ */

#endif /* child_mgnt.h */

/*-----------------============== End Of File ==============-----------------*/

==> schedwiclnt-0.1.1.tar.gz: schedwiclnt-0.1.1/src/child_mgnt.h <==
/* Schedwi
   Copyright (C) 2007 Herve Quatremain
     
   This file is part of Schedwi.

   Schedwi is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   Schedwi is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/* child_mgnt.h -- Manage running child processes in a linked list */

#ifndef _CHILD_MGNT_H
#define _CHILD_MGNT_H

#include <schedwi.h>

#if HAVE_SYS_TYPES_H
#include <sys/types.h>
#endif

#include <net_utils_glob.h>

/* Allow the use in C++ code.  */
#ifdef __cplusplus
extern "C" {
#endif

#if HAVE_PID_T
extern int add_child OF((pid_t child, const char *job_id));
#else
extern int add_child OF((int child, const char *job_id));
#endif

#if HAVE_PID_T
extern int delete_child OF((pid_t child, char **job_id));
#else
extern int delete_child OF((int child, char **job_id));
#endif

extern int terminate_job OF((const char *job_id));
extern void print_jobs OF((net_id *fd));

#ifdef __cplusplus
}
#endif  /* C++ */

#endif /* child_mgnt.h */

/*-----------------============== End Of File ==============-----------------*/
